summaryrefslogtreecommitdiff
path: root/nasm.c
diff options
context:
space:
mode:
Diffstat (limited to 'nasm.c')
-rw-r--r--nasm.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nasm.c b/nasm.c
index a0446d83..266b4eef 100644
--- a/nasm.c
+++ b/nasm.c
@@ -683,9 +683,9 @@ static void parse_cmdline(int argc, char **argv)
*inname = *outname = *listname = '\0';
/*
* First, process the NASM environment variable.
*/
- envreal = getenv("NASM");
+ envreal = getenv("NASMOPT");
arg = NULL;
if (envreal) {
envcopy = nasm_strdup(envreal);
@@ -683,9 +683,9 @@ static void parse_cmdline(int argc, char **argv)
*inname = *outname = *listname = '\0';
/*
- * First, process the NASM environment variable.
+ * First, process the NASMOPT environment variable.
*/